@@ -139,7 +139,7 @@ bbox_t union_bbox(bbox_t bb1, bbox_t bb2) {
 	return bb;
 }
 
-int bboxes_disjoint(bbox_t *bbox1, bbox_t *bbox2) {
+bool bboxes_disjoint(bbox_t *bbox1, bbox_t *bbox2) {
 	return
 		bbox1->empty || bbox2->empty ||
 		bbox1->min_x > bbox2->max_x ||
@@ -402,10 +402,10 @@ void write_mpoly_wkt(char *wkt_fn, mpoly_t mpoly, int split_polys) {
 }
 */
 
-int line_intersects_line(
+bool line_intersects_line(
 	vertex_t p1, vertex_t p2,
 	vertex_t p3, vertex_t p4,
-	int fail_on_coincident
+	bool fail_on_coincident
 ) {
 	if(
 		MAX(p1.x, p2.x) < MIN(p3.x, p4.x) ||
@@ -461,7 +461,7 @@ double ring_oriented_area(ring_t *c) {
 	return accum / 2.0;
 }
 
-int ring_is_ccw(ring_t *c) {
+bool ring_is_ccw(ring_t *c) {
 	return ring_oriented_area(c) > 0;
 }
 
@@ -500,7 +500,7 @@ static int ring_contains_point(ring_t *ring, double px, double py) {
 	return num_crossings & 1;
 }
 
-int polygon_contains_point(mpoly_t *mp, double px, double py) {
+bool polygon_contains_point(mpoly_t *mp, double px, double py) {
 	int num_crossings = 0;
 	for(int r_idx=0; r_idx<mp->num_rings; r_idx++) {
 		if(ring_contains_point(mp->rings+r_idx, px, py)) num_crossings++;
@@ -730,7 +730,7 @@ mpoly_t *mpoly_xy2ll_with_interp(georef_t *georef, mpoly_t *xy_poly, double tole
 */
 
 // returns length of longest raster side in meters, squared
-static double estimate_canvas_size_sq(georef_t *georef) {
+static double estimate_canvas_size_sq(georef_t *georef, double semi_major) {
 	double e1, n1, e2, n2;
 	xy2en(georef, 0, 0, &e1, &n1);
 	xy2en(georef, georef->w, 0, &e2, &n2);
@@ -745,7 +745,7 @@ static double estimate_canvas_size_sq(georef_t *georef) {
 	double size = MAX(size1, size2);
 	size *= georef->units_val * georef->units_val;
 	if(OSRIsGeographic(georef->spatial_ref)) {
-		size *= georef->semi_major * georef->semi_major;
+		size *= semi_major * semi_major;
 	}
 	return size;
 }
@@ -755,7 +755,14 @@ mpoly_t *mpoly_xy2ll_with_interp(georef_t *georef, mpoly_t *xy_poly, double tole
 	ll_poly->num_rings = xy_poly->num_rings;
 	ll_poly->rings = MYALLOC(ring_t, ll_poly->num_rings);
 	
-	double canvas_size_sq = estimate_canvas_size_sq(georef);
+	double semi_major;
+	if(georef->have_semi_major) {
+		semi_major = georef->semi_major;
+	} else {
+		semi_major = 6370997.0;
+		fprintf(stderr, "Warning: could not get globe size, assuming %lf\n", semi_major);
+	}
+	double canvas_size_sq = estimate_canvas_size_sq(georef, semi_major);
 	//printf("canvas_size_sq = %lf\n", canvas_size_sq);
 
 	// FIXME - now that we don't use ll2xy this is probably not needed:
@@ -832,8 +839,8 @@ mpoly_t *mpoly_xy2ll_with_interp(georef_t *georef, mpoly_t *xy_poly, double tole
 				double lonscale = cos(D2R * MAX(fabs(ll_m_interp.y), fabs(ll_m_proj.y)));
 				double dx = (ll_m_interp.x - ll_m_proj.x) * lonscale;
 				double dy = ll_m_interp.y - ll_m_proj.y;
-				dx *= D2R * georef->semi_major;
-				dy *= D2R * georef->semi_major;
+				dx *= D2R * semi_major;
+				dy *= D2R * semi_major;
 				double sqr_error = dx*dx + dy*dy;
 
 				// if the midpoint is this far off then something is seriously wrong
